@@ -5,9 +5,13 @@
 #include <iostream>
 #include <string>
 #include <bobcat/glob>
+#include <bobcat/errno>
 
+using namespace std;
+using namespace FBB;
 
 int main(int argc, char **argv)
+try
 {
     if (argc == 1)
     {
@@ -18,6 +22,7 @@ int main(int argc, char **argv)
     cout << "General:\n";
 
     Glob general;
+    general.verify();
 
     for (size_t idx = 0; idx < general.size(); idx++)
         cout << idx << ": " << general[idx] << endl;
@@ -25,10 +30,15 @@ int main(int argc, char **argv)
     cout << "Pattern: " << argv[1] << "\n";
 
     Glob pattern(argv[1], Glob::PERIOD, Glob::DEFAULT);
+    pattern.verify();
 
     for (size_t idx = 0; idx < pattern.size(); idx++)
         cout << idx << ": " << pattern[idx] << endl;
 
     return 0;
 }
-
+catch (Errno const &err)
+{
+    cout << err.what() << endl;
+    return err.which();
+}
