@@ -4,7 +4,7 @@ string String::lc(string const &str)
 {
     string ret(str);
 
-    for_each(ret.begin(), ret.end(), Wrap1<char>(&String::tolower));
+    for_each(ret.begin(), ret.end(), FnWrap1<char &>(&String::tolower));
 
     return ret;
 }
